diff --git a/mscore/importmidi/importmidi.cpp b/mscore/importmidi/importmidi.cpp
index 4165c5d..cb924b5 100644
--- a/mscore/importmidi/importmidi.cpp
+++ b/mscore/importmidi/importmidi.cpp
@@ -703,6 +703,9 @@ std::multimap<int, MTrack> createMTrackList(TimeSigMap *sigmap, const MidiFile *
                         }
                   else if (e.type() == ME_PROGRAM)
                         track.program = e.dataB();
+                  else if (e.type() == ME_CONTROLLER && e.controller() == CTRL_VOLUME) {
+                        track.volumes.insert({tick, e.value()});
+                        }
                   }
             if (hasNotes) {
                   ++trackIndex;
diff --git a/mscore/importmidi/importmidi_inner.cpp b/mscore/importmidi/importmidi_inner.cpp
index aee81f6..d39028a 100644
--- a/mscore/importmidi/importmidi_inner.cpp
+++ b/mscore/importmidi/importmidi_inner.cpp
@@ -30,6 +30,7 @@ MTrack::MTrack(const MTrack &other)
       , division(other.division)
       , isDivisionInTps(other.isDivisionInTps)
       , hadInitialNotes(other.hadInitialNotes)
+      , volumes(other.volumes)
       , chords(other.chords)
       {
       updateTupletsFromChords();
@@ -46,6 +47,7 @@ MTrack& MTrack::operator=(MTrack other)
       std::swap(division, other.division);
       std::swap(isDivisionInTps, other.isDivisionInTps);
       std::swap(hadInitialNotes, other.hadInitialNotes);
+      std::swap(volumes, other.volumes);
       std::swap(chords, other.chords);
       updateTupletsFromChords();
 
diff --git a/mscore/importmidi/importmidi_inner.h b/mscore/importmidi/importmidi_inner.h
index 8a8c0c3..7b31924 100644
--- a/mscore/importmidi/importmidi_inner.h
+++ b/mscore/importmidi/importmidi_inner.h
@@ -83,6 +83,7 @@ class MTrack {
       bool isDivisionInTps;       // ticks per second
       bool hadInitialNotes;
 
+      std::multimap<ReducedFraction, int> volumes;
       std::multimap<ReducedFraction, MidiChord> chords;
       std::multimap<ReducedFraction, MidiTuplet::TupletData> tuplets;   // <tupletOnTime, ...>
 
diff --git a/mscore/importmidi/importmidi_instrument.cpp b/mscore/importmidi/importmidi_instrument.cpp
index 8a7dcdc..5809063 100644
--- a/mscore/importmidi/importmidi_instrument.cpp
+++ b/mscore/importmidi/importmidi_instrument.cpp
@@ -432,6 +432,16 @@ void createInstruments(Score *score, QList<MTrack> &tracks)
                   tracks[idx].staff = part->staff(i);
                   }
 
+            // only importing a single volume per track here, skip when multiple volumes
+            // are defined, or the single volume is not defined on tick 0.
+            if (track.volumes.size() == 1) {
+                  for (auto &i: track.volumes) {
+                        if (i.first == ReducedFraction(0, 1)) {
+                              part->instrument()->channel(0)->volume = i.second;
+                              }
+                        }
+                  }
+
             score->appendPart(part);
             }
       }
